pub enum ClientIdSource {
SocketAddr,
XForwardedFor(usize),
}Expand description
The source that should be used to identify the client’s IP address. To be used to configure cases where a node has infra running in front of the node that is separate from the protocol, such as a load balancer. Note that this is not the same as the client type (e.g a direct client vs a proxy client, as in the case of a fullnode driving requests from many clients).
For x-forwarded-for, the usize parameter is the number of forwarding hops between the client and the node for requests going your infra or infra provider. Example:
(client) -> { (global proxy) -> (regional proxy) -> (node) }where
{ <server>, ... }are controlled by the Node operator / their cloud provider. In this case, we set:
policy-config:
client-id-source:
x-forwarded-for: 2
...NOTE: x-forwarded-for: 0 is a special case value that can be used by Node operators to discover the number of hops that should be configured. To use:
- Set
x-forwarded-for: 0for theclient-id-sourcein the config. - Run the node and query any endpoint (AuthorityServer for validator, or json rpc for rpc node) from a known IP address.
- Search for lines containing
x-forwarded-forin the logs. The log lines should contain the contents of thex-forwarded-forheader, if present, or a corresponding error if not. - The value for number of hops is derived from any such log line that
contains your known IP address, and is defined as 1 + the number of IP
addresses in the
x-forwarded-forthat occur after the known client IP address. Example:
[<known client IP>] <--- number of hops is 1
["1.2.3.4", <known client IP>, "5.6.7.8", "9.10.11.12"] <--- number of hops is 3Variants